@@ -1,7 +1,5 @@
 import subprocess
 import os
-import neuronum
-import json
 import platform
 import glob
 import asyncio
@@ -12,7 +10,10 @@ from pathlib import Path
 import requests
 import psutil
 from datetime import datetime
-
+import sys
+import json
+from cryptography.hazmat.primitives.asymmetric import ec
+from cryptography.hazmat.primitives import serialization
 
 @click.group()
 def cli():
@@ -223,6 +224,7 @@ def delete_cell():
         return
 
     confirm = click.confirm(f" Are you sure you want to delete '{host}'?", default=True)
+    os.remove(env_path)
     if not confirm:
         click.echo("Deletion canceled.")
         return
@@ -249,17 +251,14 @@ def delete_cell():
 
 
 @click.command()
-@click.option('--sync', multiple=True, default=None, help="Optional stream IDs for sync.")
-@click.option('--stream', multiple=True, default=None, help="Optional stream ID for stream.")
-@click.option('--app', is_flag=True, help="Generate a Node with app template")
-def init_node(sync, stream, app):
+def init_node():
     descr = click.prompt("Node description: Type up to 25 characters").strip()
     if descr and len(descr) > 25:
         click.echo("Description too long. Max 25 characters allowed.")
         return
-    asyncio.run(async_init_node(sync, stream, app, descr))
+    asyncio.run(async_init_node(descr))
 
-async def async_init_node(sync, stream, app, descr):
+async def async_init_node(descr):
     credentials_folder_path = Path.home() / ".neuronum"
     env_path = credentials_folder_path / ".env"
 
@@ -271,6 +270,7 @@ async def async_init_node(sync, stream, app, descr):
                 key, value = line.strip().split("=")
                 env_data[key] = value
 
+
         host = env_data.get("HOST", "")
         password = env_data.get("PASSWORD", "")
         network = env_data.get("NETWORK", "")
@@ -296,280 +296,272 @@ async def async_init_node(sync, stream, app, descr):
             async with session.post(url, json=node) as response:
                 response.raise_for_status()
                 data = await response.json()
-                nodeID = data["nodeID"]
+                node_id = data["nodeID"]
         except aiohttp.ClientError as e:
             click.echo(f"Error sending request: {e}")
             return
 
-    node_filename = "node_" + nodeID.replace("::node", "")
+    node_filename = descr + "_" + node_id.replace("::node", "")
     project_path = Path(node_filename)
     project_path.mkdir(exist_ok=True)
 
-    cell = neuronum.Cell(
-        host=host,         
-        password=password,                         
-        network=network,                        
-        synapse=synapse
-    )
+    try:
+        private_key = ec.generate_private_key(ec.SECP256R1())
+        public_key = private_key.public_key()
 
-    cells = await cell.list_cells()
-    tx = await cell.list_tx()
-    ctx = await cell.list_ctx()
-    stx = await cell.list_stx()
-    nodes = await cell.list_nodes()
+        pem_private = private_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.PKCS8,
+            encryption_algorithm=serialization.NoEncryption()
+        )
 
-    await asyncio.to_thread((project_path / "cells.json").write_text, json.dumps(cells, indent=4))
-    await asyncio.to_thread((project_path / "transmitters.json").write_text, json.dumps(tx, indent=4))
-    await asyncio.to_thread((project_path / "circuits.json").write_text, json.dumps(ctx, indent=4))
-    await asyncio.to_thread((project_path / "streams.json").write_text, json.dumps(stx, indent=4))
-    await asyncio.to_thread((project_path / "nodes.json").write_text, json.dumps(nodes, indent=4))
+        pem_public = public_key.public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.SubjectPublicKeyInfo
+        )
 
-    env_path = project_path / ".env"
-    await asyncio.to_thread(env_path.write_text, f"NODE={nodeID}\nHOST={host}\nPASSWORD={password}\nNETWORK={network}\nSYNAPSE={synapse}\n")
+        public_key_pem_file = project_path / "public_key.pem"
+        with open(public_key_pem_file, "wb") as key_file:
+            key_file.write(pem_public) 
 
-    nodemd_path = project_path / "NODE.md"
-    await asyncio.to_thread(nodemd_path.write_text, """### NODE.md: How to interact with this Node
+        private_key_pem_file = project_path / "private_key.pem"
+        with open(private_key_pem_file, "wb") as key_file:
+            key_file.write(pem_private) 
 
-```json
-{
-    "gateways": [
-        {
-            "type": "stream",
-            "id": "id::stx",
-            "link": "https://neuronum.net/stream/id::stx",
-            "info": "stream info"
-        },
-        {
-            "type": "transmitter",
-            "id": "id::tx",
-            "link": "https://neuronum.net/tx/id::tx",
-            "info": "transmitter info"
-        },
-        {
-            "type": "circuit",
-            "id": "id::ctx",
-            "link": "https://neuronum.net/circuit/id::ctx",
-            "info": "circuit info"
-        }
-    ]
-}
-```"""
-)
+        pem_public_str = pem_public.decode('utf-8')
+        pem_public_oneline = "".join(pem_public_str.split())
 
-    stx = sync[0] if sync else (stream[0] if stream else host.replace("::cell", "::stx"))
-
-    if sync:
-        for stx in sync:
-            sync_path = project_path / f"sync_{stx.replace('::stx', '')}.py"
-            sync_path.write_text(f"""\
+        current_directory = os.getcwd()
+        private_key_file = os.path.join(current_directory / project_path, "private_key.pem")
+        public_key_file = os.path.join(current_directory / project_path, "public_key.pem")
+    except:
+        print("Error creating Private/Public Key Pair")
+                                                                                                           
+    app_path = project_path / "app.py"
+    app_path.write_text(f"""\
 import asyncio
-import neuronum
-import os
-from dotenv import load_dotenv
-
-load_dotenv()
-host = os.getenv("HOST")
-password = os.getenv("PASSWORD")
-network = os.getenv("NETWORK")
-synapse = os.getenv("SYNAPSE")
-
+import neuronum                       
+from jinja2 import Environment, FileSystemLoader   
+          
+env = Environment(loader=FileSystemLoader('.'))
+template = env.get_template('ping.html')    
+                                          
 cell = neuronum.Cell(
-    host=host,
-    password=password,
-    network=network,
-    synapse=synapse
+    private_key_path="{private_key_file}",
+    public_key_path="{public_key_file}"                   
 )
-
-async def main():
-    STX = "{stx}"
-    async for operation in cell.sync(STX):
-        label = operation.get("label")
-        data = operation.get("data")
-        ts = operation.get("time")
-        stxID = operation.get("stxID")
-        operator = operation.get("operator")
-        print(label, data, ts, stxID, operator)
-
-asyncio.run(main())
-""")
-
-
-    if stream:
-        for stx in stream:
-            stream_path = project_path / f"stream_{stx.replace('::stx', '')}.py"
-            stream_path.write_text(f"""\
-import asyncio
-import neuronum
-import os
-from dotenv import load_dotenv
-import time                                   
-
-load_dotenv()
-host = os.getenv("HOST")
-password = os.getenv("PASSWORD")
-network = os.getenv("NETWORK")
-synapse = os.getenv("SYNAPSE")
-
-cell = neuronum.Cell(
-    host=host,
-    password=password,
-    network=network,
-    synapse=synapse
-)
-
-async def main():
-    STX = "{stx}"
-    label = "your_label"
     
-    while True:
-        data = {{
-            "key1": "value1",
-            "key2": "value2",
-            "key3": "value3",
-        }}
-        await cell.stream(label, data, STX)
-        time.sleep(5) 
+async def main():    
+  
+    node_id = "{node_id}"                                              
+    async for transmitter in cell.sync(node_id):   
+        ts = transmitter.get("time")
+        data = transmitter.get("data")
+        transmitter_id = transmitter.get("transmitter_id")   
+        client = transmitter.get("operator")
+        client_public_key = data.get("publicKey")  
+        action = data.get("action")
 
-asyncio.run(main())
-""")
-    
-    if not sync and not stream and not app:
-        sync_path = project_path / f"sync_{stx.replace('::stx', '')}.py"
-        sync_path.write_text(f"""\
-import asyncio
-import neuronum
-import os
-from dotenv import load_dotenv
-
-load_dotenv()
-host = os.getenv("HOST")
-password = os.getenv("PASSWORD")
-network = os.getenv("NETWORK")
-synapse = os.getenv("SYNAPSE")
-
-cell = neuronum.Cell(
-    host=host,
-    password=password,
-    network=network,
-    synapse=synapse
-)
-
-async def main():
-    async for operation in cell.sync():
-        message = operation.get("data").get("message")
-        print(message)
-
-asyncio.run(main())
-""")
+        response_data = {{}}
+              
+        if action == "ping_node":
         
-        stream_path = project_path / f"stream_{stx.replace('::stx', '')}.py"
-        stream_path.write_text(f"""\
-import asyncio
-import neuronum
-import os
-from dotenv import load_dotenv
-import time                               
+            html_content = template.render(client=client, ts=ts, data=action, transmitter_id=transmitter_id)
 
-load_dotenv()
-host = os.getenv("HOST")
-password = os.getenv("PASSWORD")
-network = os.getenv("NETWORK")
-synapse = os.getenv("SYNAPSE")
-
-cell = neuronum.Cell(
-    host=host,
-    password=password,
-    network=network,
-    synapse=synapse
-)
-
-async def main():
-    label = "Welcome to Neuronum"
-    
-    while True:
-        data = {{
-            "message": "Hello, Neuronum!"
-        }}
-        await cell.stream(label, data)
-        time.sleep(5)                       
+            response_data = {{
+                "json": f"{{transmitter_id}} - Reply from {node_id}: Pinged by {{client}} at {{ts}} with action: {{action}}",
+                "html": html_content
+            }}
+            
+            await cell.tx_response(transmitter_id, response_data, client_public_key)
 
 asyncio.run(main())
 """)
-        
-    if app and nodeID:
-
-        descr = f"{nodeID} App"                                                  
-        partners = ["private"]                                      
-        stxID = await cell.create_stx(descr, partners)  
-
-
-        descr = f"Greet {nodeID}"                                           
-        key_values = {                                                          
-            "say": "hello",
-        }
-        STX = stxID                                                     
-        label = "say:hello"                                                                                                                                                         
-        partners = ["private"]                                                   
-        txID = await cell.create_tx(descr, key_values, STX, label, partners)
-
-
-        app_path = project_path / "app.py"
-        app_path.write_text(f"""\
-import asyncio
-import neuronum
-import os
-from dotenv import load_dotenv
-
-load_dotenv()
-host = os.getenv("HOST")
-password = os.getenv("PASSWORD")
-network = os.getenv("NETWORK")
-synapse = os.getenv("SYNAPSE")
-
-cell = neuronum.Cell(
-    host=host,
-    password=password,
-    network=network,
-    synapse=synapse
-)
-
-async def main():      
-    STX = "{stxID}"                                          
-    async for operation in cell.sync(STX):       
-        txID = operation.get("txID")
-        client = operation.get("operator")                    
-                            
-        if txID == "{txID}":             
-            data = {{
-                "json": f"Hello {{client}} from {nodeID}",
-                "html": f\"\"\"
+    
+    html_path = project_path / "ping.html"
+    html_content = f"""\
 <!DOCTYPE html>
 <html>
   <head>
-    <meta charset="UTF-8">
-    <title>Greeting Node</title>
+    <style>
+      body {{
+        font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif;
+        background-color: #121212;
+        color: #e0e0e0;
+        margin: 0;
+        padding: 0;
+        display: flex;
+        justify-content: center;
+        align-items: center;
+        min-height: 100vh;
+      }}
+
+      .container {{
+        background-color: #1e1e1e;
+        border-radius: 12px;
+        padding: 40px;
+        box-shadow: 0 4px 20px rgba(0, 0, 0, 0.5);
+        width: 100%;
+        max-width: 500px;
+        text-align: center;
+        box-sizing: border-box;
+      }}
+
+      .logo {{
+        width: 80px;
+        margin-bottom: 25px;
+        filter: drop-shadow(0 0 5px rgba(255, 255, 255, 0.1));
+      }}
+
+      h1 {{
+        font-size: 1.5em;
+        font-weight: 600;
+        margin-bottom: 5px;
+        color: #f5f5f5;
+      }}
+
+      .subtitle {{
+        font-size: 0.9em;
+        color: #a0a0a0;
+        margin-bottom: 30px;
+      }}
+
+      .data-row {{
+        background-color: #2a2a2a;
+        padding: 12px 15px;
+        border-radius: 8px;
+        margin-bottom: 10px;
+        display: flex;
+        justify-content: space-between;
+        align-items: center;
+      }}
+
+      .data-label {{
+        font-weight: 400;
+        color: #a0a0a0;
+        margin: 0;
+      }}
+
+      .data-value {{
+        font-weight: 500;
+        color: #e0e0e0;
+        margin: 0;
+      }}
+
+      .data-value.truncated {{
+        white-space: nowrap;
+        overflow: hidden;
+        text-overflow: ellipsis;
+        max-width: 60%;
+      }}
+
+      .data-value.client {{
+          color: #8cafff;
+      }}
+      .data-value.timestamp {{
+          color: #a1e8a1;
+      }}
+      .data-value.transmitter-id {{
+          color: #f7a2a2;
+      }}
+      .api-button {{
+        background: #01c07d 100%;
+        color: white;
+        border: none;
+        border-radius: 8px;
+        padding: 12px 24px;
+        font-size: 16px;
+        font-weight: bold;
+        box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
+        cursor: pointer;
+        margin-top: 10px;
+      }}
+    </style>
   </head>
   <body>
-    <div class="card">
-      <h1>Hello, {{client}}</h1>
-      <p>Greetings from <span class="node">{nodeID}</span></p>
+    <div class="container">
+      <img class="logo" src="https://neuronum.net/static/logo.png" alt="Neuronum Logo">
+      
+      <h1>Reply from {node_id}</h1>
+      <p class="subtitle">Pinged successfully.</p>
+      
+      <div class="data-row">
+        <p class="data-label">Client</p>
+        <p class="data-value client">{{{{client}}}}</p>
+      </div>
+      
+      <div class="data-row">
+        <p class="data-label">Timestamp</p>
+        <p class="data-value timestamp">{{{{ts}}}}</p>
+      </div>
+      
+      <div class="data-row">
+        <p class="data-label">Data</p>
+        <p class="data-value">{{{{data}}}}</p>
+      </div>
+      
+      <div class="data-row">
+        <p class="data-label">Transmitter ID</p>
+        <p class="data-value transmitter-id truncated">{{{{transmitter_id}}}}</p>
+      </div>
+
+      <button id="send-request-btn" class="api-button">Ping again</button>
     </div>
+
+    <script>
+        document.getElementById('send-request-btn').addEventListener('click', () => {{
+            const messagePayload = {{
+                type: 'iframe_request',
+                endpoint: 'https://neuronum.net/browser/api/activate_tx/{node_id}',
+                data: {{ "action": "ping_node" }},
+                nodePublicKey: '{pem_public_oneline}',
+            }};
+
+            if (window.parent) {{
+                window.parent.postMessage(messagePayload, '*');
+            }}
+        }});
+    </script>
+
   </body>
 </html>
-\"\"\"
+"""
+    html_path.write_text(html_content)
+    config_path = project_path / "config.json"
+    await asyncio.to_thread(
+    config_path.write_text,
+f"""{{
+  "app_metadata": {{
+    "name": "{descr}",
+    "version": "1.0.0",
+    "author": "{host}"
+  }},
+  "data_gateways": [
+    {{
+      "node_id": "{node_id}",
+      "actions": [
+        {{
+          "action": "ping_node",
+          "info": "Ping Node"
+        }}
+      ]
+    }}
+  ],
+  "legals": {{
+    "terms": "https://url_to_your/terms",
+    "privacy_policy": "https://url_to_your/privacy_policy"
+  }},
+  "public_key": "{pem_public_oneline}"
+}}"""
 
-            }}
-            await cell.tx_response(txID, client, data)
-
-asyncio.run(main())
-""")
-        
-    click.echo(f"Neuronum Node '{nodeID}' initialized!")
+)
+    click.echo(f"Neuronum Node '{node_id}' initialized!")
 
 
 @click.command()
 @click.option('--d', is_flag=True, help="Start node in detached mode")
 def start_node(d):
+    update_node_at_start()
     pid_file = Path.cwd() / "status.txt"
     system_name = platform.system()
     active_pids = []
@@ -600,27 +592,24 @@ def start_node(d):
     click.echo("Starting Node...")
 
     project_path = Path.cwd()
-    script_files = glob.glob("sync_*.py") + glob.glob("stream_*.py") + glob.glob("app.py")
+    script_files = glob.glob("app.py")
     processes = []
 
     for script in script_files:
         script_path = project_path / script
         if script_path.exists():
-            python_cmd = "pythonw" if system_name == "Windows" else "python"
 
             if d:
                 process = subprocess.Popen(
-                    ["nohup", python_cmd, str(script_path), "&"] if system_name != "Windows"
-                    else [python_cmd, str(script_path)],
+                    ["nohup", sys.executable, str(script_path), "&"] if system_name != "Windows"
+                    else ["pythonw", str(script_path)],
                     stdout=subprocess.DEVNULL,
                     stderr=subprocess.DEVNULL,
                     start_new_session=True
                 )
             else:
                 process = subprocess.Popen(
-                    ["python", str(script_path)],
-                    stdout = None,
-                    stderr = None
+                    [sys.executable, str(script_path)]
                 )
 
             processes.append(process.pid)
@@ -640,14 +629,12 @@ def start_node(d):
 def check_node():
     click.echo("Checking Node status...")
 
-    env_data = {}
     try:
-        with open(".env", "r") as f:
-            for line in f:
-                if "=" in line:
-                    key, value = line.strip().split("=", 1)
-                    env_data[key] = value
-        nodeID = env_data.get("NODE", "")
+        with open('config.json', 'r') as f:
+            data = json.load(f)
+
+        nodeID = data['data_gateways'][0]['node_id']
+
     except FileNotFoundError:
         click.echo("Error: .env with credentials not found")
         return
@@ -692,11 +679,6 @@ def check_node():
                 continue
 
     if running_pids:
-        for pid in running_pids:
-                proc = psutil.Process(pid)
-                mem = proc.memory_info().rss / (1024 * 1024)  # in MB
-                cpu = proc.cpu_percent(interval=0.1)
-                click.echo(f"PID {pid} → Memory: {mem:.2f} MB | CPU: {cpu:.1f}%")
         click.echo(f"Node {nodeID} is running. Active PIDs: {', '.join(map(str, running_pids))}")
     else:
         click.echo(f"Node {nodeID} is not running.")
@@ -705,19 +687,17 @@ def check_node():
 @click.command()
 @click.option('--d', is_flag=True, help="Restart node in detached mode")
 def restart_node(d):
+    update_node_at_start()
     pid_file = Path.cwd() / "status.txt"
     system_name = platform.system()
 
     start_time = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
 
-    env_data = {}
     try:
-        with open(".env", "r") as f:
-            for line in f:
-                key, value = line.strip().split("=")
-                env_data[key] = value
+        with open('config.json', 'r') as f:
+            data = json.load(f)
 
-        nodeID = env_data.get("NODE", "")
+        nodeID = data['data_gateways'][0]['node_id']
 
     except FileNotFoundError:
         print("Error: .env with credentials not found")
@@ -754,27 +734,23 @@ def restart_node(d):
 
     click.echo(f"Starting Node {nodeID}...")
     project_path = Path.cwd()
-    script_files = glob.glob("sync_*.py") + glob.glob("stream_*.py") + glob.glob("app.py")
+    script_files = glob.glob("app.py")
     processes = []
 
-    python_cmd = "pythonw" if system_name == "Windows" else "python"
-
     for script in script_files:
         script_path = project_path / script
         if script_path.exists():
             if d:
                 process = subprocess.Popen(
-                    ["nohup", python_cmd, str(script_path), "&"] if system_name != "Windows"
-                    else [python_cmd, str(script_path)],
+                    ["nohup", sys.executable, str(script_path), "&"] if system_name != "Windows"
+                    else ["pythonw", str(script_path)],
                     stdout=subprocess.DEVNULL,
                     stderr=subprocess.DEVNULL,
                     start_new_session=True
                 )
             else:
                 process = subprocess.Popen(
-                    ["python", str(script_path)],
-                    stdout = None,
-                    stderr = None
+                    [sys.executable, str(script_path)]
                 )
 
             processes.append(process.pid)
@@ -799,14 +775,11 @@ async def async_stop_node():
 
     node_pid_path = Path("status.txt")
 
-    env_data = {}
     try:
-        with open(".env", "r") as f:
-            for line in f:
-                key, value = line.strip().split("=")
-                env_data[key] = value
+        with open('config.json', 'r') as f:
+            data = json.load(f)
 
-        nodeID = env_data.get("NODE", "")
+        nodeID = data['data_gateways'][0]['node_id']
 
     except FileNotFoundError:
         print("Error: .env with credentials not found")
@@ -842,10 +815,35 @@ async def async_stop_node():
 @click.command()
 def update_node():
     click.echo("Update your Node")
-    node_type = questionary.select(
-        "Who can view your Node?:",
-        choices=["public", "private", "partners"]
-    ).ask()
+    credentials_folder_path = Path.home() / ".neuronum"
+    env_path = credentials_folder_path / ".env"
+    env_data = {}
+
+    try:
+        with open(env_path, "r") as f:
+            for line in f:
+                key, value = line.strip().split("=")
+                env_data[key] = value
+
+        host = env_data.get("HOST", "")
+
+    except FileNotFoundError:
+        click.echo("Error: .env with credentials not found")
+        return
+    except Exception as e:
+        click.echo(f"Error reading .env file: {e}")
+        return
+    
+    if host.startswith("CMTY_"):
+        node_type = questionary.select(
+            "Community Cells can only create private Nodes",
+            choices=["private"]
+        ).ask()
+    else:
+        node_type = questionary.select(
+            "Who can view your Node?:",
+            choices=["public", "private", "partners"]
+        ).ask()
     partners = "None"
     if node_type == "partners":
         prompt_msg = (
@@ -869,20 +867,26 @@ def update_node():
     asyncio.run(async_update_node(node_type, descr, partners))
 
 async def async_update_node(node_type: str, descr: str, partners:str) -> None:
+    credentials_folder_path = Path.home() / ".neuronum"
+    env_path = credentials_folder_path / ".env"
     env_data = {}
 
     try:
-        with open(".env", "r") as f:
+        with open(env_path, "r") as f:
             for line in f:
                 key, value = line.strip().split("=")
                 env_data[key] = value
 
-        nodeID = env_data.get("NODE", "")
         host = env_data.get("HOST", "")
         password = env_data.get("PASSWORD", "")
         network = env_data.get("NETWORK", "")
         synapse = env_data.get("SYNAPSE", "")
 
+        with open('config.json', 'r') as f:
+            data = json.load(f)
+
+        nodeID = data['data_gateways'][0]['node_id']
+
     except FileNotFoundError:
         click.echo("Error: .env with credentials not found")
         return
@@ -891,14 +895,14 @@ async def async_update_node(node_type: str, descr: str, partners:str) -> None:
         return
 
     try:
-        with open("NODE.md", "r") as f:
-            nodemd_file = f.read()
+        with open("config.json", "r") as f:
+            config_file = f.read()
 
     except FileNotFoundError:
-        click.echo("Error: NODE.md file not found")
+        click.echo("Error: Config File not found")
         return
     except Exception as e:
-        click.echo(f"Error reading NODE.md file: {e}")
+        click.echo(f"Error reading Config file: {e}")
         return
     
     if node_type == "partners":
@@ -911,7 +915,7 @@ async def async_update_node(node_type: str, descr: str, partners:str) -> None:
         "password": password,
         "synapse": synapse,
         "node_type": node_type,
-        "nodemd_file": nodemd_file,
+        "config_file": config_file,
         "descr": descr,
     }
 
@@ -921,32 +925,134 @@ async def async_update_node(node_type: str, descr: str, partners:str) -> None:
                 response.raise_for_status()
                 data = await response.json()
                 nodeID = data["nodeID"]
-                node_url = data["node_url"]
         except aiohttp.ClientError as e:
             click.echo(f"Error sending request: {e}")
             return
 
-    cell = neuronum.Cell(
-        host=host,
-        password=password,
-        network=network,
-        synapse=synapse
-    )
+    if node_type == "public":
+        click.echo(f"Neuronum Node '{nodeID}' updated!")
+    else:
+        click.echo(f"Neuronum Node '{nodeID}' updated!")
 
-    cells = await cell.list_cells()
-    tx = await cell.list_tx()
-    ctx = await cell.list_ctx()
-    stx = await cell.list_stx()
-    nodes = await cell.list_nodes()
 
-    await asyncio.to_thread(Path("cells.json").write_text, json.dumps(cells, indent=4))
-    await asyncio.to_thread(Path("transmitters.json").write_text, json.dumps(tx, indent=4))
-    await asyncio.to_thread(Path("circuits.json").write_text, json.dumps(ctx, indent=4))
-    await asyncio.to_thread(Path("streams.json").write_text, json.dumps(stx, indent=4))
-    await asyncio.to_thread(Path("nodes.json").write_text, json.dumps(nodes, indent=4))
+def update_node_at_start():
+    click.echo("Update your Node")
+    credentials_folder_path = Path.home() / ".neuronum"
+    env_path = credentials_folder_path / ".env"
+    env_data = {}
+
+    try:
+        with open(env_path, "r") as f:
+            for line in f:
+                key, value = line.strip().split("=")
+                env_data[key] = value
+
+        host = env_data.get("HOST", "")
+
+    except FileNotFoundError:
+        click.echo("Error: .env with credentials not found")
+        return
+    except Exception as e:
+        click.echo(f"Error reading .env file: {e}")
+        return
+    
+    if host.startswith("CMTY_"):
+        node_type = questionary.select(
+            "Community Cells can only create private Nodes",
+            choices=["private"]
+        ).ask()
+    else:
+        node_type = questionary.select(
+            "Who can view your Node?:",
+            choices=["public", "private", "partners"]
+        ).ask()
+    partners = "None"
+    if node_type == "partners":
+        prompt_msg = (
+            "Enter the list of partners who can view this Node.\n"
+            "Format: partner::cell, partner::cell, partner::cell\n"
+            "Press Enter to leave the list unchanged"
+        )
+        partners = click.prompt(
+            prompt_msg,
+            default="None",
+            show_default=False
+        ).strip()
+    descr = click.prompt(
+        "Update Node description: Type up to 25 characters, or press Enter to leave it unchanged",
+        default="None",
+        show_default=False
+    ).strip()
+    if descr and len(descr) > 25:
+        click.echo("Description too long. Max 25 characters allowed.")
+        return
+    asyncio.run(async_update_node_at_start(node_type, descr, partners))
+
+async def async_update_node_at_start(node_type: str, descr: str, partners:str) -> None:
+    credentials_folder_path = Path.home() / ".neuronum"
+    env_path = credentials_folder_path / ".env"
+    env_data = {}
+
+    try:
+        with open(env_path, "r") as f:
+            for line in f:
+                key, value = line.strip().split("=")
+                env_data[key] = value
+
+        host = env_data.get("HOST", "")
+        password = env_data.get("PASSWORD", "")
+        network = env_data.get("NETWORK", "")
+        synapse = env_data.get("SYNAPSE", "")
+
+        with open('config.json', 'r') as f:
+            data = json.load(f)
+
+        nodeID = data['data_gateways'][0]['node_id']
+
+    except FileNotFoundError:
+        click.echo("Error: .env with credentials not found")
+        return
+    except Exception as e:
+        click.echo(f"Error reading .env file: {e}")
+        return
+
+    try:
+        with open("config.json", "r") as f:
+            config_file = f.read()
+
+    except FileNotFoundError:
+        click.echo("Error: File not found")
+        return
+    except Exception as e:
+        click.echo(f"Error reading file: {e}")
+        return
+    
+    if node_type == "partners":
+        node_type = partners
+
+    url = f"https://{network}/api/update_node"
+    node = {
+        "nodeID": nodeID,
+        "host": host,
+        "password": password,
+        "synapse": synapse,
+        "node_type": node_type,
+        "config_file": config_file,
+        "descr": descr,
+    }
+
+    async with aiohttp.ClientSession() as session:
+        try:
+            async with session.post(url, json=node) as response:
+                response.raise_for_status()
+                data = await response.json()
+                nodeID = data["nodeID"]
+        except aiohttp.ClientError as e:
+            click.echo(f"Error sending request: {e}")
+            return
 
     if node_type == "public":
-        click.echo(f"Neuronum Node '{nodeID}' updated! Visit: {node_url}")
+        click.echo(f"Neuronum Node '{nodeID}' updated!")
     else:
         click.echo(f"Neuronum Node '{nodeID}' updated!")
 
@@ -956,20 +1062,26 @@ def delete_node():
     asyncio.run(async_delete_node())
 
 async def async_delete_node():
+    credentials_folder_path = Path.home() / ".neuronum"
+    env_path = credentials_folder_path / ".env"
     env_data = {}
 
     try:
-        with open(".env", "r") as f:
+        with open(env_path, "r") as f:
             for line in f:
                 key, value = line.strip().split("=")
                 env_data[key] = value
 
-        nodeID = env_data.get("NODE", "")
         host = env_data.get("HOST", "")
         password = env_data.get("PASSWORD", "")
         network = env_data.get("NETWORK", "")
         synapse = env_data.get("SYNAPSE", "")
 
+        with open('config.json', 'r') as f:
+            data = json.load(f)
+
+        nodeID = data['data_gateways'][0]['node_id']
+
     except FileNotFoundError:
         click.echo("Error: .env with credentials not found")
         return
@@ -998,145 +1110,18 @@ async def async_delete_node():
     click.echo(f"Neuronum Node '{nodeID}' deleted!")
 
 
-@click.command()
-@click.option('--tx', required=True, help="Transmitter ID")
-@click.argument('kvpairs', nargs=-1)
-def activate(tx, kvpairs):
-    try:
-        data = dict(pair.split(':', 1) for pair in kvpairs)
-    except ValueError:
-        click.echo("Invalid input. Use key:value pairs.")
-        return
-
-    asyncio.run(async_activate(tx, data))
-
-async def async_activate(tx, data):
-    credentials_folder_path = Path.home() / ".neuronum"
-    env_path = credentials_folder_path / ".env"
-    env_data = {}
-
-    try:
-        with open(env_path, "r") as f:
-            for line in f:
-                key, value = line.strip().split("=")
-                env_data[key] = value
-    except FileNotFoundError:
-        click.echo("No cell connected. Try: neuronum connect-cell")
-        return
-    except Exception as e:
-        click.echo(f"Error reading .env: {e}")
-        return
-
-    cell = neuronum.Cell(
-        host=env_data.get("HOST", ""),
-        password=env_data.get("PASSWORD", ""),
-        network=env_data.get("NETWORK", ""),
-        synapse=env_data.get("SYNAPSE", "")
-    )
-
-    tx_response = await cell.activate_tx(tx, data)
-    click.echo(tx_response)
-
-
-@click.command()
-@click.option('--ctx', required=True, help="Circuit ID")
-@click.argument('label', nargs=-1)
-def load(ctx, label):
-    if len(label) > 1 and all(Path(x).exists() for x in label):
-        label = "*"
-    else:
-        label = " ".join(label)
-
-    asyncio.run(async_load(ctx, label))
-
-
-async def async_load(ctx, label):
-    credentials_folder_path = Path.home() / ".neuronum"
-    env_path = credentials_folder_path / ".env"
-    env_data = {}
-
-    try:
-        with open(env_path, "r") as f:
-            for line in f:
-                key, value = line.strip().split("=")
-                env_data[key] = value
-    except FileNotFoundError:
-        click.echo("No cell connected. Try: neuronum connect-cell")
-        return
-    except Exception as e:
-        click.echo(f"Error reading .env: {e}")
-        return
-
-    cell = neuronum.Cell(
-        host=env_data.get("HOST", ""),
-        password=env_data.get("PASSWORD", ""),
-        network=env_data.get("NETWORK", ""),
-        synapse=env_data.get("SYNAPSE", "")
-    )
-
-    data = await cell.load(label, ctx)
-    click.echo(data)
-
-
-@click.command()
-@click.option('--stx', default=None, help="Stream ID (optional)")
-def sync(stx):
-    asyncio.run(async_sync(stx))
-
-
-async def async_sync(stx):
-    credentials_folder_path = Path.home() / ".neuronum"
-    env_path = credentials_folder_path / ".env"
-    env_data = {}
-
-    try:
-        with open(env_path, "r") as f:
-            for line in f:
-                key, value = line.strip().split("=")
-                env_data[key] = value
-    except FileNotFoundError:
-        click.echo("No cell connected. Try: neuronum connect-cell")
-        return
-    except Exception as e:
-        click.echo(f"Error reading .env: {e}")
-        return
-
-    cell = neuronum.Cell(
-        host=env_data.get("HOST", ""),
-        password=env_data.get("PASSWORD", ""),
-        network=env_data.get("NETWORK", ""),
-        synapse=env_data.get("SYNAPSE", "")
-    )
-
-    if stx:
-        print(f"Listening to Stream '{stx}'! Close connection with CTRL+C")
-    else:
-        print(f"Listening to '{cell.host}' private Stream! Close connection with CTRL+C")
-    async for operation in cell.sync() if stx is None else cell.sync(stx):
-        label = operation.get("label")                            
-        data = operation.get("data")
-        ts = operation.get("time")
-        stxID = operation.get("stxID")
-        operator = operation.get("operator")
-        txID = operation.get("txID")
-        print(label, data, ts, operator, txID, stxID)
-
-
 cli.add_command(create_cell)
 cli.add_command(connect_cell)
 cli.add_command(view_cell)
 cli.add_command(disconnect_cell)
 cli.add_command(delete_cell)
 cli.add_command(init_node)
+cli.add_command(update_node)
 cli.add_command(start_node)
 cli.add_command(restart_node)
 cli.add_command(stop_node)
 cli.add_command(check_node)
-cli.add_command(update_node)
 cli.add_command(delete_node)
-cli.add_command(activate)
-cli.add_command(load)
-cli.add_command(sync)
 
 
 if __name__ == "__main__":
